
---
# LTE IoT 12 click

> PRVIH_PAR_RECENICA_SA_PRODUCT_PAGE_DA_ISPRATE_CELINU

<p align="center">
  <img src="CLICK_IMAGE_LINK" height=300px>
</p>

[click Product page](CLICK_PRODUCT_PAGE_LINK)

---


#### Click library

- **Author**        : Stefan Ilic
- **Date**          : Aug 2023.
- **Type**          : UART type


# Software Support

We provide a library for the LTE IoT 12 Click
as well as a demo application (example), developed using MikroElektronika
[compilers](https://www.mikroe.com/necto-studio).
The demo can run on all the main MikroElektronika [development boards](https://www.mikroe.com/development-boards).

Package can be downloaded/installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

## Library Description

> This library contains API for LTE IoT 12 Click driver.

#### Standard key functions :

- `lteiot12_cfg_setup` Config Object Initialization function.
```c
void lteiot12_cfg_setup ( lteiot12_cfg_t *cfg );
```

- `lteiot12_init` Initialization function.
```c
err_t lteiot12_init ( lteiot12_t *ctx, lteiot12_cfg_t *cfg );
```

- `lteiot12_default_cfg` Click Default Configuration function.
```c
err_t lteiot12_default_cfg ( lteiot12_t *ctx );
```

#### Example key functions :

- `lteiot12_send_cmd` This function sends a specified command to the LTE IoT 12 Click module.
```c
void lteiot12_send_cmd ( lteiot12_t *ctx, char *cmd );
```

- `lteiot12_send_cmd_with_params` This function sends a command with specified parameter to the LTE IoT 12 Click module.
```c
void lteiot12_send_cmd_with_params ( lteiot12_t *ctx, char *at_cmd_buf, char *param_buf );
```

- `lteiot12_send_sms_pdu` This function sends text message to a phone number in PDU mode.
```c
err_t lteiot12_send_sms_pdu ( lteiot12_t *ctx, char *service_center_number, char *phone_number, char *sms_text );
```

## Example Description

> Application example shows device capability of connecting to the network and 
  sending SMS, TCP/UDP messages or getting GNSS data using standard "AT" commands. 

**The demo application is composed of two sections :**

### Application Init

> Sets the device configuration for sending SMS, TCP/UDP messages or getting GNSS data.

```c

void application_init ( void ) 
{
    log_cfg_t log_cfg;  /**< Logger config object. */
    lteiot12_cfg_t lteiot12_cfg;  /**< Click config object. */

    /** 
     * Logger initialization.
     * Default baud rate: 115200
     * Default log level: LOG_LEVEL_DEBUG
     * @note If USB_UART_RX and USB_UART_TX 
     * are defined as HAL_PIN_NC, you will 
     * need to define them manually for log to work. 
     * See @b LOG_MAP_USB_UART macro definition for detailed explanation.
     */
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, " Application Init " );

    // Click initialization.
    lteiot12_cfg_setup( &lteiot12_cfg );
    LTEIOT12_MAP_MIKROBUS( lteiot12_cfg, MIKROBUS_1 );
    if ( UART_ERROR == lteiot12_init( &lteiot12, &lteiot12_cfg ) ) 
    {
        log_error( &logger, " Communication init." );
        for ( ; ; );
    }
    
    log_printf( &logger, " Power on device... \r\n" );
    lteiot12_hw_reset( &lteiot12 );
    app_error_flag = lteiot12_rsp_check( &lteiot12, LTEIOT12_RSP_RDY );
    #define LTEIOT12_MIN_FUN                            "0"
    lteiot12_send_cmd_with_params( &lteiot12, LTEIOT12_CMD_CFUN, LTEIOT12_MIN_FUN );
    app_error_flag = lteiot12_rsp_check( &lteiot12, LTEIOT12_RSP_APPRDY );
    lteiot12_error_check( app_error_flag );

    lteiot12_send_cmd( &lteiot12, LTEIOT12_CMD_AT );
    app_error_flag = lteiot12_rsp_check( &lteiot12, LTEIOT12_RSP_OK  );
    lteiot12_error_check( app_error_flag );
    
    lteiot12_send_cmd( &lteiot12, LTEIOT12_CMD_ATI );
    app_error_flag = lteiot12_rsp_check( &lteiot12, LTEIOT12_RSP_OK  );
    lteiot12_error_check( app_error_flag );

    #define LTEIOT12_FULL_FUN                           "1"
    lteiot12_send_cmd_with_params( &lteiot12, LTEIOT12_CMD_CFUN, LTEIOT12_FULL_FUN );
    app_error_flag = lteiot12_rsp_check( &lteiot12, LTEIOT12_RSP_OK  );
    lteiot12_error_check( app_error_flag );
    
    #define LTEIOT12_DISABLE_PSM                        "1"
    lteiot12_send_cmd_with_params( &lteiot12, LTEIOT12_CMD_CPSMS, LTEIOT12_DISABLE_PSM );
    app_error_flag = lteiot12_rsp_check( &lteiot12, LTEIOT12_RSP_OK  );
    lteiot12_error_check( app_error_flag );
    
    #define LTEIOT12_EN_LOCATION_AND_NETWORK            "2"
    lteiot12_send_cmd_with_params( &lteiot12, LTEIOT12_CMD_CEREG, LTEIOT12_EN_LOCATION_AND_NETWORK );
    app_error_flag = lteiot12_rsp_check( &lteiot12, LTEIOT12_RSP_OK  );
    lteiot12_error_check( app_error_flag );     

    #define LTEIOT12_DISABLE_SLEEP                      "0"
    lteiot12_send_cmd_with_params( &lteiot12, LTEIOT12_CMD_QSCLK, LTEIOT12_DISABLE_SLEEP );
    app_error_flag = lteiot12_rsp_check( &lteiot12, LTEIOT12_RSP_OK  );
    lteiot12_error_check( app_error_flag );  
    
    
    lteiot12_send_cmd( &lteiot12, LTEIOT12_CMD_CIMI );
    app_error_flag = lteiot12_rsp_check( &lteiot12, LTEIOT12_RSP_OK  );
    lteiot12_error_check( app_error_flag ); 
    
    log_info( &logger, " Application Task " );
    
}

```

### Application Task

> Depending on the selected demo example, it sends an SMS message 
 (in PDU or TXT mode) or a TCP/UDP message or getting GNSS data ( position and altitude ).

```c
void application_task ( void ) 
{
    switch( app_connection_status )
    {
        case LTEIOT12_CONFIGURE_FOR_EXAMPLE:
        {
            lteiot12_config_for_example( );
            break;
        }
        case LTEIOT12_EXAMPLE:
        {
            #if ( DEMO_EXAMPLE == TCP_UDP_EXAMPLE )
                lteiot12_tcp_udp_example( );
            #elif ( DEMO_EXAMPLE == SMS_EXAMPLE )
                lteiot12_send_sms( );
                Delay_ms( 10000 );
            #elif ( DEMO_EXAMPLE == GNSS_EXAMPLE )
                #define LTEIOT12_NEMA_SENTENCE          "\"GGA\""    
                lteiot12_send_cmd_with_params( &lteiot12, LTEIOT12_CMD_QGPSGNMEA, LTEIOT12_NEMA_SENTENCE );
                lteiot12_process( &lteiot12 );
                gnss_parser_application ( app_buf );
                lteiot12_clear_app_buf ( );
                Delay_ms( 5000 );
            #endif 
            break;
        }
        default:
        {
            log_error( &logger, "Application status error! " );
            app_connection_status = LTEIOT12_CONFIGURE_FOR_EXAMPLE;
            Delay_ms( 1000 );
            break;
        }
    }
    
}
```

The full application code, and ready to use projects can be installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

**Other Mikroe Libraries used in the example:**

- MikroSDK.Board
- MikroSDK.Log
- Click.LTEIoT12

**Additional notes and informations**

Depending on the development board you are using, you may need
[USB UART click](https://www.mikroe.com/usb-uart-click),
[USB UART 2 Click](https://www.mikroe.com/usb-uart-2-click) or
[RS232 Click](https://www.mikroe.com/rs232-click) to connect to your PC, for
development systems with no UART to USB interface available on the board. UART
terminal is available in all MikroElektronika
[compilers](https://shop.mikroe.com/compilers).

---
